spoon.transports.SpoonTransport.SpoonTransportThread

spoon :: transports :: SpoonTransport :: SpoonTransportThread :: Class SpoonTransportThread |
[hide private]
[frames] | no frames]

# Class SpoonTransportThread

source code

            object --+
                     |
    threading._Verbose --+
                         |
          threading.Thread --+
                             |
                            SpoonTransportThread

Instance Methods | [hide private]
`` | __init__(self, t)
`` | run(self)
Inherited from `threading.Thread`: `__repr__`, `getName`, `isAlive`, `isDaemon`, `join`, `setDaemon`, `setName`, `start` Inherited from `threading.Thread` (private): `_set_daemon` Inherited from `threading._Verbose` (private): `_note` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, t) (Constructor) | source code
None Overrides: threading.Thread.__init__

### run(self) | source code
None Overrides: threading.Thread.run